@@ -445,10 +445,10 @@ create_toolbars ()
 		0,                      0);
 
 	find_examples ();
-	test_combo_box = gtk_combo_box_new_text ();
+	test_combo_box = gtk_combo_box_text_new ();
 	for (i = 0; i < examples->len; i++) {
 		Example *example = examples->pdata[i];
-		gtk_combo_box_append_text (GTK_COMBO_BOX (test_combo_box), example->title);
+		gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (test_combo_box), example->title);
 	}
 	gtk_combo_box_set_active (GTK_COMBO_BOX (test_combo_box), 0);
 	g_signal_connect (test_combo_box, "changed", G_CALLBACK (example_changed_cb), NULL);
@@ -766,7 +766,7 @@ on_redirect (GtkHTML *html, const gchar *url, gint delay, gpointer data) {
 
 		redirect_url = g_strdup (url);
 
-		redirect_timerId = g_timeout_add (delay * 1000,(GtkFunction) redirect_timer_event, NULL);
+		redirect_timerId = g_timeout_add (delay * 1000,(GSourceFunc) redirect_timer_event, NULL);
 	}
 }
 
@@ -822,7 +822,7 @@ on_link_clicked (GtkHTML *html, const gchar *url, gpointer data)
 }
 
 /* simulate an async object isntantiation */
-static gint
+static gboolean
 object_timeout (GtkHTMLEmbedded *eb)
 {
 	GtkWidget *w;
@@ -847,7 +847,7 @@ object_requested_cmd (GtkHTML *html, GtkHTMLEmbedded *eb, gpointer data)
 		return FALSE;
 
 	g_object_ref (eb);
-	g_timeout_add (rand () % 5000 + 1000, (GtkFunction) object_timeout, eb);
+	g_timeout_add (rand () % 5000 + 1000, (GSourceFunc) object_timeout, eb);
 	/* object_timeout (eb); */
 
 	return TRUE;
@@ -1228,29 +1228,29 @@ main (gint argc, gchar *argv[])
 	main_table = gtk_table_new (1, 4, FALSE);
 
 	gtk_table_attach (GTK_TABLE (main_table),
-                        bar,
+			bar,
                         /* X direction */       /* Y direction */
-                        0, 1,                   0, 1,
-                        GTK_EXPAND | GTK_FILL,  GTK_SHRINK,
-                        0,                      0);
+			0, 1,                   0, 1,
+			GTK_EXPAND | GTK_FILL,  GTK_SHRINK,
+			0,                      0);
 	gtk_table_attach (GTK_TABLE (main_table),
-                        create_toolbars (),
+			create_toolbars (),
                         /* X direction */       /* Y direction */
-                        0, 1,                   1, 2,
-                        GTK_EXPAND | GTK_FILL,  GTK_SHRINK,
-                        0,                      0);
+			0, 1,                   1, 2,
+			GTK_EXPAND | GTK_FILL,  GTK_SHRINK,
+			0,                      0);
 	gtk_table_attach (GTK_TABLE (main_table),
-                        scrolled_window,
+			scrolled_window,
                         /* X direction */       /* Y direction */
-                        0, 1,                   2, 3,
-                        GTK_EXPAND | GTK_FILL,  GTK_EXPAND | GTK_FILL,
-                        0,                      0);
+			0, 1,                   2, 3,
+			GTK_EXPAND | GTK_FILL,  GTK_EXPAND | GTK_FILL,
+			0,                      0);
 	gtk_table_attach (GTK_TABLE (main_table),
-                        statusbar,
+			statusbar,
                         /* X direction */       /* Y direction */
-                        0, 1,                   3, 4,
-                        GTK_EXPAND | GTK_FILL,  GTK_SHRINK,
-                        0,                      0);
+			0, 1,                   3, 4,
+			GTK_EXPAND | GTK_FILL,  GTK_SHRINK,
+			0,                      0);
 	/*app*/
 	gtk_container_add (GTK_CONTAINER (app), main_table);
 
